Module blaxel.core.client.models.job_execution_task_metadata
============================================================

Classes
-------

`JobExecutionTaskMetadata(completed_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, created_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, scheduled_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, started_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Job execution task metadata
    
    Attributes:
        completed_at (Union[Unset, str]): Completion timestamp
        created_at (Union[Unset, str]): Creation timestamp
        name (Union[Unset, str]): Task name
        scheduled_at (Union[Unset, str]): Scheduled timestamp
        started_at (Union[Unset, str]): Start timestamp
        updated_at (Union[Unset, str]): Last update timestamp
    
    Method generated by attrs for class JobExecutionTaskMetadata.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `completed_at: blaxel.core.client.types.Unset | str`
    :

    `created_at: blaxel.core.client.types.Unset | str`
    :

    `name: blaxel.core.client.types.Unset | str`
    :

    `scheduled_at: blaxel.core.client.types.Unset | str`
    :

    `started_at: blaxel.core.client.types.Unset | str`
    :

    `updated_at: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :